@@ -1,10 +1,12 @@
 import json
 import logging
+import typing as t
 from typing import Pattern, Tuple
 
 from ..input_sanitization import Sanitize
 from .base_sanitizer import BaseSanitizer
 
+
 __all__ = ['BaseSanitizer', 'InputValueError']
 
 
@@ -12,12 +14,17 @@ logger = logging.getLogger(__name__)
 
 
 class RegExSanitizer:
-    regex: Pattern
-    sanitizer: BaseSanitizer
+    regex: t.ClassVar[Pattern]
+    sanitizer: t.ClassVar[BaseSanitizer]
+    exception_msg: t.ClassVar[str]
 
     def __call__(self, data):
         self.sanitizer(data)
 
+    @classmethod
+    def log_message(cls, error, data) -> t.Tuple:
+        raise NotImplementedError
+
     @classmethod
     def _string(cls, data) -> str:
         if isinstance(data, str):
@@ -25,31 +32,27 @@ class RegExSanitizer:
         return json.dumps(data, indent=4, sort_keys=True)
 
     def __init__(self):
-        sanitize_data = type(self)
-        self.regex = sanitize_data.regex
-
         def _log_message(error, input_data):
-            raw_log_args: Tuple = sanitize_data.log_message(error, input_data)
-            return tuple([raw_log_args[0]] + [self._string(x) for x in raw_log_args[1:]])
+            raw_log_args: Tuple = type(self).log_message(error, input_data)
+            return tuple(
+                [raw_log_args[0]] + [self._string(x) for x in raw_log_args[1:]]
+            )
 
-        self.sanitizer = BaseSanitizer(
+        type(self).sanitizer = BaseSanitizer(
             self._verify,
-            sanitize_data.exception_msg if sanitize_data.exception_msg else '',
+            type(self).exception_msg if type(self).exception_msg else '',
             _log_message,
         )
 
     def _verify(self, string: str):
         try:
-            self.__verify(string)
+            if not self.regex.match(string):
+                msg = "RegEx Miss Match Error"
+                logger.error(*self.sanitizer.log_message(msg, string))
+                raise RegExMissMatchError(msg)
         except RegExMissMatchError as not_matching_regex:
             raise InputValueError(self.sanitizer.exception_msg) from not_matching_regex
 
-    def __verify(self, string: str):
-        if not self.regex.match(string):
-            msg = "RegEx Miss Match Error"
-            logger.error(*self.sanitizer.log_message(msg, string))
-            raise RegExMissMatchError(msg)
-
 
 class RegExMissMatchError(Exception):
     pass
